@@ -29,7 +29,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <kactioncollection.h>
 #include <kaction.h>
-#include <klocale.h>
+#include <KDE/KLocalizedString>
 #include <kdebug.h>
 #include <KDE/KGlobal>
 #include <KDE/KStandardDirs>
@@ -116,7 +116,15 @@ bool LookingGlassEffect::loadData()
         return false;
     }
 
-    const QString fragmentshader =  KGlobal::dirs()->findResource("data", "kwin/lookingglass.frag");
+    QString shadersDir = "kwin/shaders/1.10/";
+#ifdef KWIN_HAVE_OPENGLES
+    const qint64 coreVersionNumber = kVersionNumber(3, 0);
+#else
+    const qint64 coreVersionNumber = kVersionNumber(1, 40);
+#endif
+    if (GLPlatform::instance()->glslVersion() >= coreVersionNumber)
+        shadersDir = "kwin/shaders/1.40/";
+    const QString fragmentshader =  KGlobal::dirs()->findResource("data", shadersDir + "lookingglass.frag");
     m_shader = ShaderManager::instance()->loadFragmentShader(ShaderManager::SimpleShader, fragmentshader);
     if (m_shader->isValid()) {
         ShaderBinder binder(m_shader);
