@@ -39,12 +39,13 @@ public:
     explicit CloseWindowView(QWidget *parent = 0);
     void windowInputMouseEvent(QMouseEvent* e);
     void disarm();
-public slots:
-    void arm();
 
 Q_SIGNALS:
     void close();
 
+protected:
+    void hideEvent(QHideEvent *event);
+
 private:
     QTimer* m_armTimer;
 };
